#[non_exhaustive]pub enum ServerEvent {
RequestAccepted {
method: Method,
cseq: u32,
state: SessionState,
},
MethodNotValid {
method: Method,
state: SessionState,
},
SessionSetup {
session_id: String,
transport: Transport,
},
}Expand description
An event produced by ServerSession::handle_request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RequestAccepted
A request was accepted and the state machine advanced (2xx sent).
Fields

state: SessionStateThe state after handling.
MethodNotValid
A request was rejected in the current state; a 455 was returned.
Fields

state: SessionStateThe state the request was rejected in.
SessionSetup
A SETUP completed and a session id was allocated / reused.